@@ -28,7 +28,8 @@ from gs_quant.base import get_enum_value, Base
 from gs_quant.common import Currency
 from gs_quant.common import FieldValueMap, AssetClass
 from gs_quant.errors import MqValueError
-from gs_quant.instrument import EqOption, EqVarianceSwap, FXOption, FXBinary, Instrument, IRSwaption
+from gs_quant.instrument import EqOption, EqVarianceSwap, FXOption, FXBinary, FXCorrelationSwap, FXOneTouch, \
+    FXVarianceSwap, FXVolatilitySwap, Instrument, IRSwaption
 from gs_quant.target.backtests import BacktestResult, BacktestRisk, \
     BacktestTradingQuantityType, DeltaHedgeParameters, \
     BacktestSignalSeriesItem, \
@@ -45,7 +46,7 @@ ISO_FORMAT = r"^([0-9]{4})-([0-9]{2})-([0-9]{2})$"
 class StrategySystematic:
     """Equity back testing systematic strategy"""
     _supported_eq_instruments = (EqOption, EqVarianceSwap)
-    _supported_fx_instruments = (FXOption, FXBinary)
+    _supported_fx_instruments = (FXOption, FXBinary, FXCorrelationSwap, FXOneTouch, FXVarianceSwap, FXVolatilitySwap)
     _supported_ir_instruments = (IRSwaption,)
     _supported_instruments = _supported_eq_instruments + _supported_fx_instruments + _supported_ir_instruments
 
@@ -67,6 +68,7 @@ class StrategySystematic:
                  roll_date_mode: str = None,
                  expiry_date_mode: str = None,
                  cash_accrual: bool = True,
+                 combine_roll_signal_entries: bool = False,
                  transaction_cost_config: TransactionCostConfig = None,
                  use_xasset_backtesting_service: bool = False):
         self.__cost_netting = cost_netting
@@ -132,7 +134,8 @@ class StrategySystematic:
                                                         roll_date_mode is not None else None,
                                                         market_model=EquityMarketModel(market_model) if
                                                         market_model else None,
-                                                        cash_accrual=cash_accrual)
+                                                        cash_accrual=cash_accrual,
+                                                        combine_roll_signal_entries=combine_roll_signal_entries)
 
         backtest_parameters_class: Base = getattr(backtests, self.__backtest_type + 'BacktestParameters')
         backtest_parameter_args = {
