@@ -14,16 +14,16 @@ specific language governing permissions and limitations
 under the License.
 """
 import datetime as dt
-from typing import Iterable, Optional, Tuple, Union
+from typing import Iterable, Optional, Tuple, Union, Type
 
 from gs_quant.base import InstrumentBase, RiskKey
 from gs_quant.common import RiskMeasure
-from gs_quant.datetime.date import date_range, prev_business_date
+from gs_quant.datetime.date import date_range
 from gs_quant.risk import RollFwd, MarketDataScenario
 from gs_quant.risk.results import HistoricalPricingFuture, PricingFuture
-
 from .core import PricingContext
 from .markets import CloseMarket
+from ..api.risk import GenericRiskApi
 
 
 class HistoricalPricingContext(PricingContext):
@@ -46,7 +46,8 @@ class HistoricalPricingContext(PricingContext):
             market_data_location: Optional[str] = None,
             timeout: Optional[int] = None,
             show_progress: Optional[bool] = None,
-            use_server_cache: Optional[bool] = None):
+            use_server_cache: Optional[bool] = None,
+            provider: Optional[Type[GenericRiskApi]] = None):
         """
         A context for producing valuations over multiple dates
 
@@ -78,7 +79,7 @@ class HistoricalPricingContext(PricingContext):
         super().__init__(is_async=is_async, is_batch=is_batch, use_cache=use_cache, visible_to_gs=visible_to_gs,
                          request_priority=request_priority, csa_term=csa_term,
                          market_data_location=market_data_location, timeout=timeout, show_progress=show_progress,
-                         use_server_cache=use_server_cache)
+                         use_server_cache=use_server_cache, use_historical_diddles_only=True, provider=provider)
 
         if start is not None:
             if dates is not None:
@@ -94,13 +95,12 @@ class HistoricalPricingContext(PricingContext):
             raise ValueError('Must supply start or dates')
 
     def _market(self, date: dt.date, location: str) -> CloseMarket:
-        date = prev_business_date(date) if date == dt.date.today() else date
-        return CloseMarket(location=location, date=date, check=False)
+        return CloseMarket(location=location, date=date, check=True)
 
     def calc(self, instrument: InstrumentBase, risk_measure: RiskMeasure) -> PricingFuture:
         futures = []
 
-        provider = instrument.provider
+        provider = instrument.provider if self.provider is None else self.provider
         scenario = self._scenario
         parameters = self._parameters
         location = self.market.location
@@ -136,7 +136,8 @@ class BackToTheFuturePricingContext(HistoricalPricingContext):
             market_data_location: Optional[str] = None,
             timeout: Optional[int] = None,
             show_progress: Optional[bool] = None,
-            name: Optional[str] = None):
+            name: Optional[str] = None,
+            provider: Optional[Type[GenericRiskApi]] = None):
         """
         A context for producing valuations over multiple dates
 
@@ -167,7 +168,7 @@ class BackToTheFuturePricingContext(HistoricalPricingContext):
         super().__init__(start=start, end=end, calendars=calendars, dates=dates,
                          is_async=is_async, is_batch=is_batch, use_cache=use_cache, visible_to_gs=visible_to_gs,
                          csa_term=csa_term, market_data_location=market_data_location,
-                         timeout=timeout, show_progress=show_progress)
+                         timeout=timeout, show_progress=show_progress, provider=provider)
         self._roll_to_fwds = roll_to_fwds
         self.name = name
         if start is not None:
@@ -186,7 +187,7 @@ class BackToTheFuturePricingContext(HistoricalPricingContext):
     def calc(self, instrument: InstrumentBase, risk_measure: RiskMeasure) -> PricingFuture:
         futures = []
 
-        provider = instrument.provider
+        provider = instrument.provider if self.provider is None else self.provider
         base_scenario = self._scenario
         parameters = self._parameters
         location = self.market.location
