@@ -27,7 +27,9 @@ class DataSetType(EnumBase, Enum):
     
     """Type of the dataset"""
 
-    PlotTool_Pro = 'PlotTool Pro'    
+    PlotTool_Pro = 'PlotTool Pro'
+    Alloy = 'Alloy'
+    Snowflake = 'Snowflake'    
 
 
 class DelayExclusionType(EnumBase, Enum):    
@@ -89,6 +91,23 @@ class AdvancedFilter(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class AlloyService(Base):
+    base_url: Optional[str] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class ColumnEnumPair(Base):
+    column: Optional[str] = field(default=None, metadata=field_metadata)
+    enum_key: Optional[str] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -201,11 +220,13 @@ class MarketDataFilteredField(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
-class MeasureBacktest(DictBase):
+@dataclass
+class MeasureBacktest(Base):
     pass
 
 
-class MeasureKpi(DictBase):
+@dataclass
+class MeasureKpi(Base):
     pass
 
 
@@ -229,6 +250,10 @@ class ParserEntity(Base):
     only_mqtick_fields: Optional[bool] = field(default=None, metadata=field_metadata)
     include_trd_flg_proc: Optional[bool] = field(default=None, metadata=field_metadata)
     keep_raw_fields: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    include_mmt: Optional[bool] = field(default=None, metadata=field_metadata)
+    include_currency: Optional[bool] = field(default=None, metadata=field_metadata)
+    separate_quote_exchange_codes: Optional[bool] = field(default=None, metadata=field_metadata)
+    trade_ids: Optional[bool] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -260,6 +285,14 @@ class ResponseInfo(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class StoredEntity(Base):
+    stored_processor_name: Optional[str] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -269,6 +302,15 @@ class SymbolFilterLink(Base):
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class AlloyConfig(Base):
+    data_service: Optional[AlloyService] = field(default=None, metadata=field_metadata)
+    coverage_service: Optional[AlloyService] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -311,49 +353,12 @@ class DataSetDelay(Base):
 class DataSetFieldEntityStringParameters(Base):
     enum: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     format_: Optional[FieldFormat] = field(default=None, metadata=config(field_name='format', exclude=exclude_none))
-    pattern: Optional[str] = field(default='^[\w ]{1,256}$', metadata=field_metadata)
+    pattern: Optional[str] = field(default=r'^[\w ]{1,256}$', metadata=field_metadata)
     max_length: Optional[int] = field(default=None, metadata=field_metadata)
     min_length: Optional[int] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class DataSetParameters(Base):
-    frequency: str = field(default=None, metadata=field_metadata)
-    category: Optional[str] = field(default=None, metadata=field_metadata)
-    sub_category: Optional[str] = field(default=None, metadata=field_metadata)
-    methodology: Optional[str] = field(default=None, metadata=field_metadata)
-    coverage: Optional[str] = field(default=None, metadata=field_metadata)
-    coverages: Optional[Tuple[AssetType, ...]] = field(default=None, metadata=field_metadata)
-    notes: Optional[str] = field(default=None, metadata=field_metadata)
-    history: Optional[str] = field(default=None, metadata=field_metadata)
-    sample_start: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
-    sample_end: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
-    published_date: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
-    history_date: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
-    asset_class: Optional[AssetClass] = field(default=None, metadata=field_metadata)
-    owner_ids: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
-    support_ids: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
-    support_distribution_list: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
-    apply_market_data_entitlements: Optional[bool] = field(default=None, metadata=field_metadata)
-    upload_data_policy: Optional[str] = field(default=None, metadata=field_metadata)
-    logical_db: Optional[str] = field(default=None, metadata=field_metadata)
-    symbol_strategy: Optional[str] = field(default=None, metadata=field_metadata)
-    underlying_data_set_id: Optional[str] = field(default=None, metadata=field_metadata)
-    immutable: Optional[bool] = field(default=None, metadata=field_metadata)
-    include_in_catalog: Optional[bool] = field(default=False, metadata=field_metadata)
-    coverage_enabled: Optional[bool] = field(default=True, metadata=field_metadata)
-    use_created_time_for_upload: Optional[bool] = field(default=None, metadata=field_metadata)
-    apply_entity_entitlements: Optional[bool] = field(default=None, metadata=field_metadata)
-    development_status: Optional[DevelopmentStatus] = field(default=None, metadata=field_metadata)
-    internal_owned: Optional[bool] = field(default=None, metadata=field_metadata)
-    cr_limit_read: Optional[int] = field(default=None, metadata=field_metadata)
-    cr_limit_write: Optional[int] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
@@ -410,7 +415,9 @@ class ProcessorEntity(Base):
     parsers: Optional[Tuple[ParserEntity, ...]] = field(default=None, metadata=field_metadata)
     deduplicate: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     enum_type: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    enums: Optional[Tuple[ColumnEnumPair, ...]] = field(default=None, metadata=field_metadata)
     fill_fwd: Optional[str] = field(default=None, metadata=field_metadata)
+    stored: Optional[Tuple[StoredEntity, ...]] = field(default=None, metadata=field_metadata)
     additional_processors: Optional[Tuple[QueryProcessor, ...]] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
@@ -460,6 +467,7 @@ class DataQuery(Base):
     end_time: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
     relative_start_date: Optional[str] = field(default=None, metadata=field_metadata)
     relative_end_date: Optional[str] = field(default=None, metadata=field_metadata)
+    adjust_as_of: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
     as_of_time: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
     id_as_of_date: Optional[datetime.date] = field(default=None, metadata=field_metadata)
     use_temporal_x_ref: Optional[bool] = field(default=False, metadata=field_metadata)
@@ -472,6 +480,7 @@ class DataQuery(Base):
     samples: Optional[int] = field(default=None, metadata=field_metadata)
     limit: Optional[int] = field(default=None, metadata=field_metadata)
     polling_interval: Optional[int] = field(default=None, metadata=field_metadata)
+    group_by: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
     grouped: Optional[bool] = field(default=None, metadata=field_metadata)
     fields: Optional[Tuple[Union[DictBase, str], ...]] = field(default=None, metadata=field_metadata)
     restrict_fields: Optional[bool] = field(default=False, metadata=field_metadata)
@@ -491,7 +500,128 @@ class DataQuery(Base):
     multi_trading_session: Optional[bool] = field(default=None, metadata=field_metadata)
     multi_session: Optional[bool] = field(default=None, metadata=field_metadata)
     quote_consolidation: Optional[bool] = field(default=None, metadata=field_metadata)
+    consolidation: Optional[bool] = field(default=None, metadata=field_metadata)
+    primary: Optional[bool] = field(default=None, metadata=field_metadata)
     time_index: Optional[str] = field(default=None, metadata=field_metadata)
+    empty_intervals: Optional[bool] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class DataSetFieldEntity(Base):
+    name: str = field(default=None, metadata=field_metadata)
+    description: str = field(default=None, metadata=field_metadata)
+    type_: str = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
+    id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
+    classifications: Optional[DataSetFieldEntityClassifications] = field(default=None, metadata=field_metadata)
+    unique: Optional[bool] = field(default=False, metadata=field_metadata)
+    field_java_type: Optional[str] = field(default=None, metadata=field_metadata)
+    parameters: Optional[Union[DataSetFieldEntityNumberParameters, DataSetFieldEntityStringParameters]] = field(default=None, metadata=field_metadata)
+    entitlements: Optional[Entitlements] = field(default=None, metadata=field_metadata)
+    metadata: Optional[EntityMetadata] = field(default=None, metadata=field_metadata)
+    attributes: Optional[DataSetFieldEntityAttributes] = field(default=None, metadata=field_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class DataSetParameters(Base):
+    frequency: str = field(default=None, metadata=field_metadata)
+    category: Optional[str] = field(default=None, metadata=field_metadata)
+    sub_category: Optional[str] = field(default=None, metadata=field_metadata)
+    methodology: Optional[str] = field(default=None, metadata=field_metadata)
+    coverage: Optional[str] = field(default=None, metadata=field_metadata)
+    coverages: Optional[Tuple[AssetType, ...]] = field(default=None, metadata=field_metadata)
+    notes: Optional[str] = field(default=None, metadata=field_metadata)
+    history: Optional[str] = field(default=None, metadata=field_metadata)
+    sample_start: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
+    sample_end: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
+    published_date: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
+    history_date: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
+    asset_class: Optional[AssetClass] = field(default=None, metadata=field_metadata)
+    owner_ids: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    support_ids: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    support_distribution_list: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    apply_market_data_entitlements: Optional[bool] = field(default=None, metadata=field_metadata)
+    upload_data_policy: Optional[str] = field(default=None, metadata=field_metadata)
+    logical_db: Optional[str] = field(default=None, metadata=field_metadata)
+    symbol_strategy: Optional[str] = field(default=None, metadata=field_metadata)
+    underlying_data_set_id: Optional[str] = field(default=None, metadata=field_metadata)
+    immutable: Optional[bool] = field(default=None, metadata=field_metadata)
+    include_in_catalog: Optional[bool] = field(default=False, metadata=field_metadata)
+    coverage_enabled: Optional[bool] = field(default=True, metadata=field_metadata)
+    use_created_time_for_upload: Optional[bool] = field(default=None, metadata=field_metadata)
+    apply_entity_entitlements: Optional[bool] = field(default=None, metadata=field_metadata)
+    development_status: Optional[DevelopmentStatus] = field(default=None, metadata=field_metadata)
+    internal_owned: Optional[bool] = field(default=None, metadata=field_metadata)
+    cr_limit_read: Optional[int] = field(default=None, metadata=field_metadata)
+    cr_limit_write: Optional[int] = field(default=None, metadata=field_metadata)
+    alloy_config: Optional[AlloyConfig] = field(default=None, metadata=field_metadata)
+    external_distribution: Optional[bool] = field(default=None, metadata=field_metadata)
+    snowflake_db: Optional[str] = field(init=False, default='TIMESERIES', metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class DataSetTransformation(Base):
+    transforms: DataSetTransforms = field(default=None, metadata=field_metadata)
+    condition: Optional[DataSetCondition] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class DeleteCoverageQuery(Base):
+    where: Optional[FieldFilterMapDataQuery] = field(default=None, metadata=field_metadata)
+    delete_all: Optional[bool] = field(default=False, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class FieldColumnPair(Base):
+    field_: Optional[str] = field(default=None, metadata=config(field_name='field', exclude=exclude_none))
+    column: Optional[str] = field(default=None, metadata=field_metadata)
+    field_description: Optional[str] = field(default=None, metadata=field_metadata)
+    link: Optional[FieldLink] = field(default=None, metadata=field_metadata)
+    aliases: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
+    display_alias: Optional[str] = field(default=None, metadata=field_metadata)
+    resolvable: Optional[bool] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class HistoryFilter(Base):
+    absolute_start: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
+    absolute_end: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
+    relative_start_seconds: Optional[float] = field(default=None, metadata=field_metadata)
+    relative_end_seconds: Optional[float] = field(default=None, metadata=field_metadata)
+    delay: Optional[Union[DataSetDelay, Tuple[DataSetDelay, ...]]] = field(default=None, metadata=field_metadata)
+    name: Optional[str] = field(default=None, metadata=name_metadata)
+
+
+@handle_camel_case_args
+@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass(unsafe_hash=True, repr=False)
+class DataQueryResponse(Base):
+    type_: str = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
+    request_id: Optional[str] = field(default=None, metadata=field_metadata)
+    error_message: Optional[str] = field(default=None, metadata=field_metadata)
+    id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
+    total_pages: Optional[int] = field(default=None, metadata=field_metadata)
+    data_set_id: Optional[str] = field(default=None, metadata=field_metadata)
+    entity_type: Optional[MeasureEntityType] = field(default=None, metadata=field_metadata)
+    delay: Optional[int] = field(default=None, metadata=field_metadata)
+    data: Optional[Tuple[FieldValueMap, ...]] = field(default=None, metadata=field_metadata)
+    groups: Optional[Tuple[DataGroup, ...]] = field(default=None, metadata=field_metadata)
     name: Optional[str] = field(default=None, metadata=name_metadata)
 
 
@@ -523,89 +653,12 @@ class DataSetCatalogEntry(Base):
     mdapi: Optional[MDAPI] = field(default=None, metadata=field_metadata)
 
 
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class DataSetFieldEntity(Base):
-    name: str = field(default=None, metadata=field_metadata)
-    description: str = field(default=None, metadata=field_metadata)
-    type_: str = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
-    id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
-    classifications: Optional[DataSetFieldEntityClassifications] = field(default=None, metadata=field_metadata)
-    unique: Optional[bool] = field(default=False, metadata=field_metadata)
-    field_java_type: Optional[str] = field(default=None, metadata=field_metadata)
-    parameters: Optional[DictBase] = field(default=None, metadata=field_metadata)
-    entitlements: Optional[Entitlements] = field(default=None, metadata=field_metadata)
-    metadata: Optional[EntityMetadata] = field(default=None, metadata=field_metadata)
-    attributes: Optional[DataSetFieldEntityAttributes] = field(default=None, metadata=field_metadata)
-
-
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class DataSetTransformation(Base):
-    transforms: DataSetTransforms = field(default=None, metadata=field_metadata)
-    condition: Optional[DataSetCondition] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class DeleteCoverageQuery(Base):
-    where: Optional[FieldFilterMapDataQuery] = field(default=None, metadata=field_metadata)
-    delete_all: Optional[bool] = field(default=False, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class FieldColumnPair(Base):
-    field_: Optional[str] = field(default=None, metadata=config(field_name='field', exclude=exclude_none))
-    column: Optional[str] = field(default=None, metadata=field_metadata)
-    field_description: Optional[str] = field(default=None, metadata=field_metadata)
-    link: Optional[FieldLink] = field(default=None, metadata=field_metadata)
-    aliases: Optional[Tuple[str, ...]] = field(default=None, metadata=field_metadata)
-    resolvable: Optional[bool] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class HistoryFilter(Base):
-    absolute_start: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
-    absolute_end: Optional[datetime.datetime] = field(default=None, metadata=field_metadata)
-    relative_start_seconds: Optional[float] = field(default=None, metadata=field_metadata)
-    relative_end_seconds: Optional[float] = field(default=None, metadata=field_metadata)
-    delay: Optional[DictBase] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
-@handle_camel_case_args
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass(unsafe_hash=True, repr=False)
-class DataQueryResponse(Base):
-    type_: str = field(default=None, metadata=config(field_name='type', exclude=exclude_none))
-    request_id: Optional[str] = field(default=None, metadata=field_metadata)
-    error_message: Optional[str] = field(default=None, metadata=field_metadata)
-    id_: Optional[str] = field(default=None, metadata=config(field_name='id', exclude=exclude_none))
-    total_pages: Optional[int] = field(default=None, metadata=field_metadata)
-    data_set_id: Optional[str] = field(default=None, metadata=field_metadata)
-    entity_type: Optional[MeasureEntityType] = field(default=None, metadata=field_metadata)
-    delay: Optional[int] = field(default=None, metadata=field_metadata)
-    data: Optional[Tuple[FieldValueMap, ...]] = field(default=None, metadata=field_metadata)
-    groups: Optional[Tuple[DataGroup, ...]] = field(default=None, metadata=field_metadata)
-    name: Optional[str] = field(default=None, metadata=name_metadata)
-
-
 @handle_camel_case_args
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass(unsafe_hash=True, repr=False)
 class DataSetDimensions(Base):
+    time_field: str = field(default=None, metadata=field_metadata)
     symbol_dimensions: Tuple[str, ...] = field(default=None, metadata=field_metadata)
-    time_field: Optional[str] = field(default=None, metadata=field_metadata)
     transaction_time_field: Optional[str] = field(default=None, metadata=field_metadata)
     symbol_dimension_properties: Optional[Tuple[FieldColumnPair, ...]] = field(default=None, metadata=field_metadata)
     non_symbol_dimensions: Optional[Tuple[FieldColumnPair, ...]] = field(default=None, metadata=field_metadata)
