@@ -14,8 +14,9 @@ specific language governing permissions and limitations
 under the License.
 """
 
-import datetime
+import datetime as dt
 
+import numpy as np
 import pandas as pd
 import pytest
 from pandas.testing import assert_series_equal
@@ -23,18 +24,18 @@ from testfixtures import Replacer
 from testfixtures.mock import Mock
 
 from gs_quant.timeseries import VolReference
-from gs_quant.timeseries.backtesting import Basket, basket_series, MqValueError, MqTypeError, RebalFreq, date, \
-    DataContext, np
+from gs_quant.timeseries.backtesting import Basket, basket_series, MqValueError, MqTypeError, RebalFreq, \
+    DataContext
 
 
 def test_basket_series():
     dates = [
-        datetime.datetime(2019, 1, 1),
-        datetime.datetime(2019, 1, 2),
-        datetime.datetime(2019, 1, 3),
-        datetime.datetime(2019, 1, 4),
-        datetime.datetime(2019, 1, 5),
-        datetime.datetime(2019, 1, 6),
+        dt.datetime(2019, 1, 1),
+        dt.datetime(2019, 1, 2),
+        dt.datetime(2019, 1, 3),
+        dt.datetime(2019, 1, 4),
+        dt.datetime(2019, 1, 5),
+        dt.datetime(2019, 1, 6),
     ]
 
     x = pd.Series([100.0, 101, 103.02, 100.9596, 100.9596, 102.978792], index=dates)
@@ -51,18 +52,18 @@ def test_basket_series():
         basket_series([1, 2, 3], [1])
 
     dates = [
-        datetime.datetime(2019, 1, 1),
-        datetime.datetime(2019, 1, 2),
-        datetime.datetime(2019, 1, 3),
-        datetime.datetime(2019, 1, 4),
-        datetime.datetime(2019, 1, 5),
-        datetime.datetime(2019, 1, 6),
-        datetime.datetime(2019, 2, 1),
-        datetime.datetime(2019, 2, 2),
-        datetime.datetime(2019, 2, 3),
-        datetime.datetime(2019, 2, 4),
-        datetime.datetime(2019, 2, 5),
-        datetime.datetime(2019, 2, 6),
+        dt.datetime(2019, 1, 1),
+        dt.datetime(2019, 1, 2),
+        dt.datetime(2019, 1, 3),
+        dt.datetime(2019, 1, 4),
+        dt.datetime(2019, 1, 5),
+        dt.datetime(2019, 1, 6),
+        dt.datetime(2019, 2, 1),
+        dt.datetime(2019, 2, 2),
+        dt.datetime(2019, 2, 3),
+        dt.datetime(2019, 2, 4),
+        dt.datetime(2019, 2, 5),
+        dt.datetime(2019, 2, 6),
     ]
     mreb = pd.Series(
         [100.0, 101, 103.02, 100.9596, 100.9596, 102.978792,
@@ -70,6 +71,36 @@ def test_basket_series():
         index=dates)
     assert_series_equal(mreb, basket_series([mreb], [1], rebal_freq=RebalFreq.MONTHLY))
 
+    dates = [
+        dt.datetime(2019, 1, 1),
+        dt.datetime(2019, 1, 2),
+        dt.datetime(2019, 1, 3),
+        dt.datetime(2019, 1, 4),
+        dt.datetime(2019, 1, 5),
+        dt.datetime(2019, 1, 8),
+        dt.datetime(2019, 1, 9),
+        dt.datetime(2019, 1, 10),
+        dt.datetime(2019, 1, 11),
+        dt.datetime(2019, 1, 12),
+        dt.datetime(2019, 1, 13)
+    ]
+    wreb = pd.Series(
+        [100.0, 105, 110, 115, 120, 125,
+         130, 135, 140, 145, 150],
+        index=dates)
+
+    wreb_2 = pd.Series(
+        [100.0, 105, 110, 115, 120, 125,
+         130, 135, 140, 145, 150],
+        index=dates)
+
+    ret_wreb = pd.Series(
+        [100.0, 110.0, 120.0, 130.0, 140.0, 150.0,
+         162.0, 174.0, 186.0, 198.0, 210.0],
+        index=dates)
+
+    assert_series_equal(ret_wreb, basket_series([wreb, wreb_2], [1, 1], rebal_freq=RebalFreq.WEEKLY))
+
 
 def _mock_spot_data():
     dates = pd.date_range(start='2021-01-01', periods=6)
@@ -77,7 +108,7 @@ def _mock_spot_data():
     x['assetId'] = 'MA4B66MW5E27U9VBB94'
     y = pd.DataFrame({'spot': [100.0, 100, 100, 100, 100, 100]}, index=dates)
     y['assetId'] = 'MA4B66MW5E27UAL9SUX'
-    return x.append(y)
+    return pd.concat([x, y])
 
 
 def _mock_spot_data_feb():
@@ -86,17 +117,18 @@ def _mock_spot_data_feb():
     x['assetId'] = 'MA4B66MW5E27U9VBB94'
     y = pd.DataFrame({'spot': [100.0, 101.5, 100.02, 98.1, 95.3, 93.9]}, index=dates_feb)
     y['assetId'] = 'MA4B66MW5E27UAL9SUX'
-    return x.append(y)
+    return pd.concat([x, y])
 
 
 def test_basket_price():
     with pytest.raises(MqValueError):
         Basket(['AAPL UW'], [0.1, 0.9], RebalFreq.MONTHLY)
 
-    dates = pd.DatetimeIndex([date(2021, 1, 1), date(2021, 1, 2), date(2021, 1, 3), date(2021, 1, 4), date(2021, 1, 5),
-                              date(2021, 1, 6)])
-    dates_feb = pd.DatetimeIndex([date(2021, 2, 1), date(2021, 2, 2), date(2021, 2, 3), date(2021, 2, 4),
-                                  date(2021, 2, 5), date(2021, 2, 6)])
+    dates = pd.DatetimeIndex(
+        [dt.date(2021, 1, 1), dt.date(2021, 1, 2), dt.date(2021, 1, 3), dt.date(2021, 1, 4), dt.date(2021, 1, 5),
+         dt.date(2021, 1, 6)])
+    dates_feb = pd.DatetimeIndex([dt.date(2021, 2, 1), dt.date(2021, 2, 2), dt.date(2021, 2, 3), dt.date(2021, 2, 4),
+                                  dt.date(2021, 2, 5), dt.date(2021, 2, 6)])
 
     replace = Replacer()
 
@@ -132,14 +164,15 @@ def test_basket_price():
 def test_basket_average_implied_vol():
     replace = Replacer()
 
-    dates = pd.DatetimeIndex([date(2021, 1, 1), date(2021, 1, 2), date(2021, 1, 3), date(2021, 1, 4), date(2021, 1, 5),
-                              date(2021, 1, 6)])
+    dates = pd.DatetimeIndex(
+        [dt.date(2021, 1, 1), dt.date(2021, 1, 2), dt.date(2021, 1, 3), dt.date(2021, 1, 4), dt.date(2021, 1, 5),
+         dt.date(2021, 1, 6)])
 
     x = pd.DataFrame({'impliedVolatility': [30.0, 30.2, 29.8, 30.6, 30.1, 30.0]}, index=dates)
     x['assetId'] = 'MA4B66MW5E27U9VBB94'
     y = pd.DataFrame({'impliedVolatility': [20.0, 20.2, 20.3, 20.6, 21.1, 20.0]}, index=dates)
     y['assetId'] = 'MA4B66MW5E27UAL9SUX'
-    implied_vol = x.append(y)
+    implied_vol = pd.concat([x, y])
     implied_vol.index.name = 'date'
 
     mock_spot = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
@@ -171,10 +204,11 @@ def test_basket_average_implied_vol():
 def test_basket_average_realized_vol():
     replace = Replacer()
 
-    dates = pd.DatetimeIndex([date(2021, 1, 1), date(2021, 1, 2), date(2021, 1, 3), date(2021, 1, 4), date(2021, 1, 5),
-                              date(2021, 1, 6)])
-    dates_feb = pd.DatetimeIndex([date(2021, 2, 1), date(2021, 2, 2), date(2021, 2, 3), date(2021, 2, 4),
-                                  date(2021, 2, 5), date(2021, 2, 6)])
+    dates = pd.DatetimeIndex(
+        [dt.date(2021, 1, 1), dt.date(2021, 1, 2), dt.date(2021, 1, 3), dt.date(2021, 1, 4), dt.date(2021, 1, 5),
+         dt.date(2021, 1, 6)])
+    dates_feb = pd.DatetimeIndex([dt.date(2021, 2, 1), dt.date(2021, 2, 2), dt.date(2021, 2, 3), dt.date(2021, 2, 4),
+                                  dt.date(2021, 2, 5), dt.date(2021, 2, 6)])
 
     mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
     mock_data.side_effect = [_mock_spot_data(), _mock_spot_data_feb(), _mock_spot_data_feb()]
@@ -207,7 +241,7 @@ def test_basket_average_realized_vol():
     mock_get_last = replace('gs_quant.timeseries.measures.get_last_for_measure', Mock())
     mock_get_last.return_value = None
     # Test case where ts.get_last_for_measure returns none
-    with DataContext('2021-02-01', datetime.date.today() + datetime.timedelta(days=2)):
+    with DataContext('2021-02-01', dt.date.today() + dt.timedelta(days=2)):
         a_basket.average_realized_volatility('2d')
 
     replace.restore()
@@ -225,7 +259,7 @@ def _mock_data_simple():
     y['assetId'] = 'XLB_MOCK_MQID'
     z = pd.DataFrame({'spot': (a ** 3).tolist()}, index=a.index)
     z['assetId'] = 'SPX_MOCK_MQID'
-    return x.append(y).append(z)
+    return pd.concat([x, y, z])
 
 
 def _mock_spot_data_identical():
@@ -234,7 +268,7 @@ def _mock_spot_data_identical():
     x['assetId'] = 'MA4B66MW5E27U9VBB94'
     y = pd.DataFrame({'spot': [100.0, 101, 103.02, 100.9596, 100.9596, 102.978792]}, index=dates)
     y['assetId'] = 'MA4B66MW5E27UAL9SUX'
-    return x.append(y)
+    return pd.concat([x, y])
 
 
 def _mock_spot_data_corr():
@@ -242,7 +276,7 @@ def _mock_spot_data_corr():
     x = pd.DataFrame({'spot': [78, 9, 1003, 17, -12, 5], 'assetId': 'MA4B66MW5E27U9VBB94'}, index=dates)
     y = pd.DataFrame({'spot': [-33, 33, 15, 21, -3, 2], 'assetId': 'MA4B66MW5E27UAL9SUX'}, index=dates)
     z = pd.DataFrame({'spot': [86, 86, 56, 86, 86, 9], 'assetId': 'MA4B66MW5E27UANZH2M'}, index=dates)
-    return x.append(y).append(z)
+    return pd.concat([x, y, z])
 
 
 def test_basket_average_realized_vol_wts():
@@ -260,7 +294,7 @@ def test_basket_average_realized_vol_wts():
 
     a_basket = Basket(['XLC UP', 'XLP UP', 'SPX'], [0.2, 0.3, 0.5], RebalFreq.DAILY)
 
-    with DataContext(start=date(2021, 9, 1), end=date(2021, 9, 25)):
+    with DataContext(start=dt.date(2021, 9, 1), end=dt.date(2021, 9, 25)):
         av_realized_vol = a_basket.average_realized_volatility('2d')
         np.testing.assert_approx_equal(av_realized_vol.iloc[0], 2.3)
 
@@ -270,8 +304,8 @@ def test_basket_average_realized_vol_wts():
 def test_basket_average_realized_vol_intraday():
     replace = Replacer()
 
-    end_date = date.today()
-    start_date = end_date - datetime.timedelta(days=4)
+    end_date = dt.date.today()
+    start_date = end_date - dt.timedelta(days=4)
 
     a = pd.Series([1 for i in range(5)], index=pd.date_range(start_date, end_date))
     z = pd.DataFrame({'spot': (a ** 3).tolist()}, index=a.index)
@@ -285,13 +319,13 @@ def test_basket_average_realized_vol_intraday():
 
     mock_today = replace('gs_quant.timeseries.get_last_for_measure', Mock())
     mock_today.side_effect = [pd.DataFrame({'assetId': 'SPX_MOCK_MQID', 'spot': 5001.0},
-                                           index=[datetime.datetime.now()])]
+                                           index=[dt.datetime.now()])]
 
     a_basket = Basket(['SPX'], [1], RebalFreq.DAILY)
 
-    with DataContext(start=start_date, end=date.today()):
+    with DataContext(start=start_date, end=dt.date.today()):
         avg_vol = a_basket.average_realized_volatility('2d')
-        assert avg_vol.index[-1].date() == date.today()
+        assert avg_vol.index[-1].date() == dt.date.today()
 
     replace.restore()
 
@@ -299,8 +333,9 @@ def test_basket_average_realized_vol_intraday():
 def test_basket_average_realized_corr():
     replace = Replacer()
 
-    dates = pd.DatetimeIndex([date(2021, 1, 1), date(2021, 1, 2), date(2021, 1, 3), date(2021, 1, 4), date(2021, 1, 5),
-                              date(2021, 1, 6)])
+    dates = pd.DatetimeIndex(
+        [dt.date(2021, 1, 1), dt.date(2021, 1, 2), dt.date(2021, 1, 3), dt.date(2021, 1, 4), dt.date(2021, 1, 5),
+         dt.date(2021, 1, 6)])
 
     mock_data = replace('gs_quant.timeseries.backtesting.ts.get_historical_and_last_for_measure', Mock())
     mock_data.side_effect = [_mock_spot_data_identical(), _mock_spot_data_corr(),
@@ -384,8 +419,9 @@ def test_basket_without_weights():
 def test_basket_avg_fwd_vol():
     replace = Replacer()
 
-    dates = pd.DatetimeIndex([date(2021, 1, 1), date(2021, 1, 2), date(2021, 1, 3), date(2021, 1, 4), date(2021, 1, 5),
-                              date(2021, 1, 6)])
+    dates = pd.DatetimeIndex(
+        [dt.date(2021, 1, 1), dt.date(2021, 1, 2), dt.date(2021, 1, 3), dt.date(2021, 1, 4), dt.date(2021, 1, 5),
+         dt.date(2021, 1, 6)])
 
     x_1m = pd.DataFrame({'impliedVolatility': [30.0, 30.2, 29.8, 30.6, 30.1, 30.0]}, index=dates)
     x_1m['assetId'] = 'MA4B66MW5E27U9VBB94'
