@@ -15,10 +15,16 @@
 # should be fully documented: docstrings should describe parameters and the return value, and provide a 1-line
 # description. Type annotations should be provided for parameters.
 import re
+from enum import Enum
+from numbers import Real
+from typing import Union
+
+import pandas as pd
 
 from gs_quant.datetime import relative_date_add
-from gs_quant.timeseries.datetime import *
-from .helper import plot_function
+from . import align
+from .helper import plot_function, Window, Interpolate
+from ..errors import MqValueError
 
 """
 Timeseries analysis library contains functions used to analyze properties of timeseries, including laging, differencing,
@@ -26,14 +32,21 @@ autocorrelation, co-integration and other operations
 """
 
 
+class ThresholdType(str, Enum):
+    percentage = "percentage"
+    absolute = "absolute"
+
+
 @plot_function
-def smooth_spikes(x: pd.Series, threshold: float) -> pd.Series:
+def smooth_spikes(x: pd.Series, threshold: float,
+                  threshold_type: ThresholdType = ThresholdType.percentage) -> pd.Series:
     """
     Smooth out the spikes of a series. If a point is larger/smaller than (1 +/- threshold) times both neighbors, replace
     it with the average of those neighbours. Note: the first and last points in the input series are dropped.
 
     :param x: timeseries
     :param threshold: minimum increment to trigger filter
+    :param threshold_type: type of threshold check
     :return: smoothed timeseries
 
     **Usage**
@@ -51,19 +64,31 @@ def smooth_spikes(x: pd.Series, threshold: float) -> pd.Series:
 
     :func:`exponential_moving_average`
     """
+
+    def check_percentage(previous, current, next_, multiplier) -> bool:
+        current_higher = current > previous * multiplier and current > next_ * multiplier
+        current_lower = previous > current * multiplier and next_ > current * multiplier
+        return current_higher or current_lower
+
+    def check_absolute(previous, current, next_, absolute) -> bool:
+        current_higher = current > previous + absolute and current > next_ + absolute
+        current_lower = previous > current + absolute and next_ > current + absolute
+        return current_higher or current_lower
+
     if len(x) < 3:
         return pd.Series(dtype=float)
 
+    threshold_value, check_spike = (threshold, check_absolute) if threshold_type == ThresholdType.absolute else (
+        (1 + threshold), check_percentage)
+
     result = x.copy()
-    multiplier = (1 + threshold)
     current, next_ = x.iloc[0:2]
     for i in range(1, len(x) - 1):
         previous = current
         current = next_
         next_ = x.iloc[i + 1]
 
-        scaled = current * multiplier
-        if (current > previous * multiplier and current > next_ * multiplier) or (previous > scaled and next_ > scaled):
+        if check_spike(previous, current, next_, threshold_value):
             result.iloc[i] = (previous + next_) / 2
 
     return result[1:-1]
@@ -85,6 +110,8 @@ def repeat(x: pd.Series, n: int = 1) -> pd.Series:
     """
     if not 0 < n < 367:
         raise MqValueError('n must be between 0 and 367')
+    if x.empty:
+        return x
     index = pd.date_range(freq=f'{n}D', start=x.index[0], end=x.index[-1])
     return x.reindex(index, method='ffill')
 
@@ -117,7 +144,7 @@ def first(x: pd.Series) -> pd.Series:
     :func:`last`
 
     """
-    return pd.Series(x[0], x.index)
+    return pd.Series(x.iloc[0], x.index)
 
 
 @plot_function
@@ -343,7 +370,7 @@ def lag(x: pd.Series, obs: Union[Window, int, str] = 1, mode: LagMode = LagMode.
             y.index += pd.DateOffset(years=int(match.group(1)))
             y = y.groupby(y.index).first()
         else:
-            y.index += pd.DateOffset(relative_date_add(obs))
+            y.index = pd.DatetimeIndex([(i + pd.DateOffset(relative_date_add(obs))).date() for i in y.index])
 
         if mode == LagMode.EXTEND:
             return y
@@ -352,6 +379,8 @@ def lag(x: pd.Series, obs: Union[Window, int, str] = 1, mode: LagMode = LagMode.
     obs = getattr(obs, 'w', obs)
     # Determine how we want to handle observations prior to start date
     if mode == LagMode.EXTEND:
+        if x.empty:
+            return x
         if x.index.resolution != 'day':
             raise MqValueError(f'unable to extend index with resolution {x.index.resolution}')
         kwargs = {'periods': abs(obs) + 1, 'freq': 'D'}
